//
//  ViewController.m
//  CJLSimpleSerchBar
//
//  Created by xalo on 16/8/8.
//  Copyright © 2016年 蓝鸥科技. All rights reserved.
//

#import "ViewController.h"
// 遵守 tableView 的协议
@interface ViewController ()<UISearchBarDelegate,UITableViewDataSource,UITableViewDelegate,UISearchResultsUpdating>
// tableView
@property (weak, nonatomic) IBOutlet UITableView *searchTableView;
// 数组列表
@property (nonatomic, weak) NSArray *allDataArray;
// 查询结果数组列表
@property (nonatomic, retain) NSMutableArray *resultMArray;

// UISearchController 不能用 storyBoard创建？
@property (nonatomic, strong) UISearchController *searchController;

// 定义一个全局变量接收选择了哪一个 scope
@property (nonatomic, assign) NSInteger selectedIndex;
@end

@implementation ViewController

// 数组列表懒加载
-(NSArray *)allDataArray {
    if (!_allDataArray) {
        // plist 文件存储到数组中
        NSString *plistPath = [[NSBundle mainBundle] pathForResource:@"team" ofType:@"plist"];
        // 初始化数组
        self.allDataArray = [NSArray arrayWithContentsOfFile:plistPath];
    }
    return _allDataArray;
}
// 查询结果数组懒加载
-(NSMutableArray *)resultMArray {
    if (!_resultMArray) {
        _resultMArray = [NSMutableArray array];
    }
    return _resultMArray;
}


// 自定义查询方法
- (void)filterQueryWithImputText:(NSString *)text scopeIndex:(NSInteger)index {
    // 创建谓词
    NSPredicate *predicate;
    if (text.length == 0) { // 没有进行查询操作
        self.resultMArray = [NSMutableArray arrayWithArray:self.allDataArray];
        [self.searchTableView reloadData];
        return;
    }else  {
        // 判断 选择的判断条件
        switch (index) {
            case 0:{ // 按照中文搜索
                predicate = [NSPredicate predicateWithFormat:@"SELF.name contains[c]%@",text];
            }
                
                break;
            case 1:{ // 按照英文搜索
                predicate = [NSPredicate predicateWithFormat:@"SELF.image contains[c]%@",text];
            }
                break;
            default:
                break;
        }
        // 查询结果数组
        self.resultMArray = (NSMutableArray *)[self.allDataArray filteredArrayUsingPredicate:predicate];
    }
    [self.searchTableView reloadData];
    NSLog(@"%@",self.resultMArray);
}





- (void)viewDidLoad {
    [super viewDidLoad];
    
    // 注册Cell
    [self.searchTableView registerClass:[UITableViewCell class] forCellReuseIdentifier:@"CELL"];
    self.searchController.dimsBackgroundDuringPresentation = NO;
    self.searchController.hidesNavigationBarDuringPresentation = NO;
    // 初始化 UISearchBarController
    self.searchController = [[UISearchController alloc] initWithSearchResultsController:nil];
    // 将tableView 的头部视图设置为 searchBar视图
    self.searchController.searchBar.frame = CGRectMake(self.searchController.searchBar.frame.origin.x, self.searchController.searchBar.frame.origin.y, self.searchController.searchBar.frame.size.width, 44);
    self.searchTableView.tableHeaderView = self.searchController.searchBar;

    
    
 
    
    
#pragma mark 初始化之后指定代理才有效
    // 设置 searTableView 的代理
    self.searchTableView.delegate = self;
    self.searchTableView.dataSource = self;
    // 设置 searchBar 的代理
    self.searchController.searchBar.delegate = self;
#pragma mark UISearchBarUpdating  遵守更新查询结果信息
    self.searchController.searchResultsUpdater = self;
    
    
    // 设置 scope属性
    self.searchController.searchBar.scopeButtonTitles = @[@"按照中文搜索",@"按照英文搜索"];
    

    // Do any additional setup after loading the view, typically from a nib.
}
#pragma mark UISearchBarDelegate
// 判断选择了哪一个 scopeTitle
-(void)searchBar:(UISearchBar *)searchBar selectedScopeButtonIndexDidChange:(NSInteger)selectedScope {
    // 查询
    [self filterQueryWithImputText:self.searchController.searchBar.text scopeIndex:selectedScope];
    self.selectedIndex = selectedScope;
}
/**********************************需要实现的代理方法***************************************************************/
#pragma mark UISearchResultsUpdating 
// 当文本内容发生改变的时候 向表视图数据源重新发送加载消息
-(void)updateSearchResultsForSearchController:(UISearchController *)searchController {
    [self filterQueryWithImputText:self.searchController.searchBar.text scopeIndex:self.selectedIndex];
}
#pragma mark UISearchBarDelegate 
// 点击了 cancell 按钮
-(void)searchBarCancelButtonClicked:(UISearchBar *)searchBar {
    // 查询所有
    [self filterQueryWithImputText:@"" scopeIndex:-1];
}


#pragma mark tableView 的代理方法
// 返回单元格的个数
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    // 判断是展示所有数据列表还是查询结果列表/*****************************/
    if (self.searchController.searchBar.text.length != 0) {
        return self.resultMArray.count;
    }else {
         return self.allDataArray.count;
    }
    
}

// 返回 cell 的内容
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    NSDictionary *tmpDic = nil;
    // 判断是展示所有数据列表还是查询结果列表/*****************************/
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"CELL"];
    if (self.searchController.active) {  // 如果是查询状态
        tmpDic = self.resultMArray[indexPath.row];
        
    }else {  /*********查询结果cell 列表*/
        tmpDic = self.allDataArray[indexPath.row];
    }
    
    cell.textLabel.text = tmpDic[@"name"];
    cell.detailTextLabel.text = tmpDic[@"image"];
    UIImage *countryPic = [UIImage imageNamed:tmpDic[@"image"]];
    cell.imageView.image = countryPic;
    return cell;
}






















- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
